let didReceiveFirstFullList = false;

// --- Automatyczny reconnect po powrocie do karty/przywróceniu internetu ---
function reconnectIfNeeded() {
    if (!socket.connected) {
        socket.connect();
    }
}

document.addEventListener("visibilitychange", function() {
    if (!document.hidden) {
        reconnectIfNeeded();
    }
});

window.addEventListener("focus", function() {
    reconnectIfNeeded();
});

window.addEventListener("online", function() {
    reconnectIfNeeded();
});

// --- Blokowanie checkboxów na czas reconnect ---
function disableCheckboxes(disable) {
    document.querySelectorAll('#items input[type="checkbox"]').forEach(cb => {
        cb.disabled = disable;
    });
}

// --- Toasty przy rozłączeniu i połączeniu ---
let firstConnect = true;
let wasReconnected = false; // flaga do kontrolowania toasta

socket.on('connect', function() {
    if (!firstConnect) {
        //showToast('Połączono z serwerem!', 'info');
        disableCheckboxes(true);
        wasReconnected = true;

        if (window.LIST_ID && window.usernameForReconnect) {
            socket.emit('join_list', { room: window.LIST_ID, username: window.usernameForReconnect });
        }
    }
    firstConnect = false;
});

socket.on('disconnect', function(reason) {
    showToast('Utracono połączenie z serwerem...', 'warning');
    disableCheckboxes(true);
});

socket.off('joined_confirmation');
socket.on('joined_confirmation', function(data) {
    if (wasReconnected) {
        showToast(`Lista: ${data.list_title} – ponownie dołączono.`, 'info');
        wasReconnected = false;
    }
    if (window.LIST_ID) {
        socket.emit('request_full_list', { list_id: window.LIST_ID });
    }

});

socket.on('user_joined', function(data) {
    showToast(`${data.username} dołączył do listy`, 'info');
});

socket.on('user_left', function(data) {
    showToast(`${data.username} opuścił listę`, 'warning');
});

socket.on('user_list', function(data) {
    if (data.users.length > 0) {
        const userList = data.users.join(', ');
        showToast(`Obecni: ${userList}`, 'info');
    }
});

socket.on('receipt_added', function (data) {
    
  const gallery = document.getElementById("receiptGallery");
  if (!gallery) return;

  // Usuń placeholder, jeśli istnieje
  const alert = gallery.querySelector(".alert");
  if (alert) {
    alert.remove();
  }

  // Sprawdź, czy już istnieje obraz z tym URL
  const existing = Array.from(gallery.querySelectorAll("img")).find(img => img.src === data.url);
  if (!existing) {
    const col = document.createElement("div");
    col.className = "col-6 col-md-4 col-lg-3 text-center";
    col.innerHTML = `
      <a href="${data.url}" class="glightbox" data-gallery="receipt-gallery">
        <img src="${data.url}" class="img-fluid rounded shadow-sm border border-secondary" style="max-height: 200px; object-fit: cover;">
      </a>
    `;
    gallery.appendChild(col);
    lightbox.reload();
  }
});

socket.on('full_list', function (data) {
  const itemsContainer = document.getElementById('items');

  const oldItems = Array.from(
    itemsContainer.querySelectorAll('li[data-name], li[id^="item-"]')
  );

  const isDifferent = isListDifferent(oldItems, data.items);

  updateListSmoothly(data.items);
  toggleEmptyPlaceholder();

  if (didReceiveFirstFullList && isDifferent) {
    showToast('Lista została zaktualizowana', 'info');
  }
  didReceiveFirstFullList = true;
});